<?php

/**
 * @package         Google Structured Data Markup
 * @version         2.0.1 Free
 *
 * @author          Tassos Marinos <info@tassos.gr>
 * @link            http://www.tassos.gr
 * @copyright       Copyright © 2016 Tassos Marinos All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
 */

defined('_JEXEC') or die('Restricted Access');

/**
 *  Google Structured Data Helper Class
 */
class GSDHelper
{
	/**
	 *  Returns Item-based custom JSON-LD code
	 *
	 *  @param   object  $data  The item's data
	 *
	 *  @return  string         The custom JSON-LD code
	 */
	public static function getItemCustomCode($data)
	{
		if (!isset($data->customcode) || empty($data->customcode) || strpos($data->customcode, '</script>') === false)
		{
			return "";
		}

		return "\n" . $data->customcode . "\n";
	}

	/**
	 *  Returns the first x characters from the article's text
	 *
	 *  @param   object   $item    The Article object
	 *  @param   integer  $length  Maximum number of characters to use from str.
	 *
	 *  @return  string
	 */
	public static function getArticleText($item, $length = 200)
	{
		$text = $item->introtext ? $item->introtext : $item->fulltext;
		return trim(mb_substr(strip_tags($text), 0, $length));
	}

	/**
	 *  Returns the article image
	 *
	 *  @param   object  $item  The Articles object
	 *
	 *  @return  string         
	 */
	public static function getArticleImage($item)
	{
		if (isset($item->image) && !empty($item->image))
		{
			return self::absURL($item->image);
		}

		if (!isset($item->images))
		{
			return "";
		}

		$images = json_decode($item->images);
		$image  = $images->image_intro ? $images->image_intro : $images->image_fulltext;

		return JFile::exists(JPATH_SITE . "/" . $image) ? JURI::root() . $image : "";
	}

	/**
	 *  Returns image width and height
	 *
	 *  @param   string  $image  The URL of the image2wbmp(image)
	 *
	 *  @return  array
	 */
	public static function getImageSize($image)
	{
		$imageSize = $image ? getimagesize($image) : array(0, 0);
		
		$info["width"]  = $imageSize[0];
		$info["height"] = $imageSize[1];

		return $info;
	}

	/**
	 *  Prepares string for JSON output
	 *  Escapes all double quotes from string
	 *
	 *  @param   string  $str  The string to be escaped
	 *
	 *  @return  string        
	 */
	public static function escape($str)
	{
		if (!$str)
		{
			return;
		}

		return addcslashes($str, '"\\/');
	}

	/**
	 *  Returns absolute URL
	 *
	 *  @param   string  $url  The URL
	 *
	 *  @return  string
	 */
	public static function absURL($url)
	{
		$url = str_replace(JURI::root(), "", $url);
		$url = str_replace(JURI::root(true), "", $url);
		$url = ltrim($url, "/");

		return JURI::root() . $url;
	}
}

?>